@@ -9,6 +9,8 @@ import os.path
 import re
 import time
 import shutil
+import traceback
+import sys
 
 import recdblist
 import guess
@@ -72,12 +74,13 @@ def get_move_dest_path(title,temppath,recpath,ext):
             recdblist.printutf8(u"同サイズのファイルが存在します")
 
     return title
-def get_delpath(temppath,title):
+def get_delpath(temppath,title,addfp=1):
     delpath=[os.path.join(temppath,title+".ts")]
     delpath.append(os.path.join(temppath,title+".avi"))
-    delpath.append(os.path.join(temppath,title+".mp4"))
+    if addfp==1:
+        delpath.append(os.path.join(temppath,title+".mp4"))
+        delpath.append(os.path.join(temppath,title+".mkv"))
     delpath.append(os.path.join(temppath,title+".m2v"))
-    delpath.append(os.path.join(temppath,title+".mkv"))
     delpath.append(os.path.join(temppath,title+".120.avi"))
     delpath.append(os.path.join(temppath,title+".timecode.txt"))
     delpath.append(os.path.join(temppath,title+".aac"))
@@ -109,6 +112,15 @@ def execMove(title,temppath,recpath,ext,autodel):
         if os.path.exists(destpath):
             if os.path.getsize(destpath) == os.path.getsize(srcpath):
                 recdblist.printutf8(u"同名同サイズのファイルが存在します。")
+                if autodel==1:
+                    recdblist.printutf8(u"関連ファイルを削除します。")
+                    delpath=get_delpath(temppath, title)
+                    for dp in delpath:
+                        try:
+                            os.remove(dp)
+                            ""
+                        except:
+                            ""
         else:
             recdblist.printutf8("moving now..")
             recdblist.printutf8(srcpath+" : "+destpath)
@@ -122,4 +134,16 @@ def execMove(title,temppath,recpath,ext,autodel):
                         os.remove(dp)
                         ""
                     except:
-                        ""
\ No newline at end of file
+                        ""
+def execDelete(title,temppath):
+    delpath=get_delpath(temppath, title,0)
+    recdblist.printutf8(title+u"　関連の一時ファイルを削除します")
+    for dp in delpath:
+        try:
+            if os.path.exists(dp):
+                recdblist.printutf8(dp)
+                os.remove(dp)
+        except Exception, inst:
+            print type(inst)
+            print str(inst)
+            print traceback.print_exc(file=sys.stdout)
\ No newline at end of file
