@@ -25,3 +25,6 @@ def getdbpath(string):
 def getenv(string):
     global confp
     return confp.get('env', string)
+def getlog(string):
+    global confp
+    return confp.get('log', string)
