@@ -46,9 +46,9 @@ class DB_MySQL:
             epgbtime DATETIME,\
             epgetime DATETIME,\
             epgduplicate TINYINT DEFAULT 0,\
-            epgchange TINYINT DEFAULT 0\
+            epgchange TINYINT DEFAULT 0,\
             epgexp VARCHAR(200),\
-            counter TINYINT DEFAULT -1\
+            counter TINYINT DEFAULT -1,\
             UNIQUE uni (type,chtxt,title,btime,deltaday)\
             )')
         except:
@@ -1156,4 +1156,4 @@ class DB_MySQL:
         self.drop_in_settings()
         self.new_in_settings()
         self.close_db(db)
-        self.change_version_in_status("98")
\ No newline at end of file
+        self.change_version_in_status("98")
