@@ -7,6 +7,7 @@ import os
 import shutil
 import time
 import os.path
+import traceback
 
 import chdb
 import n_gram
@@ -41,7 +42,7 @@ def updatebc(bctype):
         time.sleep(5)
         rec10d.rec10db.update_by_bctype_epg_ch(bctype)
     except Exception, inst:
-        recdblist.Commonlogex("Error","updatebc(epgdb.py)", str(type(inst)), str(inst))
+        recdblist.Commonlogex("Error","updatebc(epgdb.py)", str(type(inst)), str(inst)+"\n"+traceback.format_exc(),log_level=200)
         xml2db_dom.xml2db_dom(tmppath + bctype + "epgdata.bak.xml", bctype)
         rec10d.rec10db.update_status_by_bctype_epg_ch(bctype, "2")
 def updatebc_bak(bctype):
