@@ -9,6 +9,9 @@ task names
 import datetime
 import os
 import os.path
+import traceback
+
+import configreader
 
 global REC_RESERVE
 global REC_FINAL_RESERVE
@@ -70,21 +73,37 @@ REC_AUTO_SUGGEST_AP2FP = "auto_suggest_ap2fp"
 REC_AUTO_KEYWORD = "auto_keyword"
 REC_BAYES_SUGGEST ="bayes_suggest"
 
-version = 96
-version_str="0.9.6"
-def printutf8(unicode):
+version = 98
+version_str="0.9.8"
+
+global verbose_level_now
+global log_level_now
+
+try:
+    log_level_now=int(configreader.getlog("log_level"))
+    verbose_level_now=int(configreader.getlog("verbose_level"))
+except:
+    log_level_now=900
+    verbose_level_now=400
+def printutf8(unicode,verbose_level=500):
+    if verbose_level_now > verbose_level:
+        try:
+            str=unicode.encode('utf-8')
+            print str
+        except Exception, inst:
+            recdblist.Commonlogex("Error", "printutf8(recdblist.py)", str(type(inst)), str(inst)+traceback.format_exc(),log_level=200)
+def printuft8ex(unicode,verbose_level=500,log_level=500):
     str=unicode.encode('utf-8')
-    print str
-def printuft8ex(unicode):
-    str=unicode.encode('utf-8')
-    print str
+    if verbose_level_now > verbose_level:
+        print str
     logfname="/var/log/rec10"
     mode="a"
-    if os.path.exists(logfname):
-        f=open(logfname,mode)
-        f.write(str+"\n")
-        f.close()
-def Commonlogex(type,place,inst,txt=""):
+    if log_level_now > log_level:
+        if os.path.exists(logfname):
+            f=open(logfname,mode)
+            f.write(str+"\n")
+            f.close()
+def Commonlogex(type,place,inst,txt,verbose_level=500,log_level=500):
     lt=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")+u":"
     if txt=="":
         lt=lt+u"["+type+u"] "+place+u" "+inst
@@ -93,11 +112,13 @@ def Commonlogex(type,place,inst,txt=""):
     lt=lt.encode('utf-8')
     logfname="/var/log/rec10"
     mode="a"
-    print lt
-    if os.path.exists(logfname):
-        f=open(logfname,mode)
-        f.write(lt+"\n")
-        f.close()
+    if verbose_level_now > verbose_level:
+        print lt
+    if log_level_now > log_level:
+        if os.path.exists(logfname):
+            f=open(logfname,mode)
+            f.write(lt+"\n")
+            f.close()
 def addCommandLog(tspath,log_title,cmd,cmd_log=""):
     addlog(tspath,cmd,log_title+u"ログ-コマンド")
     addlog(tspath,cmd_log,log_title+u"ログ-詳細")
