@@ -6,6 +6,7 @@
 import epgdb
 import os
 import time
+from ts2x264 import ts2x264
 import tv2avi
 import tv2mkv
 import checker
@@ -36,9 +37,10 @@ import rec10d
 #import auto_process
 import datetime
 import tv2mp4
+import ts2x264
 path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
 recpath = "/home/ftpusr/ftp-tmp/Recording/"
 ftpusr = "/home/ftpusr/ftp-tmp"
 recordedpath = u"/home/ftpusr/ftp-video"
 if __name__ == "__main__":
-    ""
\ No newline at end of file
+    print ts2x264.get_x264core_version()
\ No newline at end of file
