@@ -9,11 +9,11 @@ import re
 import sys
 import time
 import shutil
+import traceback
 
 import auto_rec
 import auto_process
 import chdb
-import checker
 import configreader
 import epgdb
 import rec10d
@@ -42,8 +42,8 @@ def task():
     recdb.delete_old_auto_keyword("1")
     tasks = recdb.getnow("3")
     inum = recdb.countRecNow_minutes("10")
-    recdblist.printutf8(u"rec10処理開始"+ datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"))
-    recdblist.printutf8(u"直近録画予約件数:" + str(inum) + u"BS/CS録画中件数:" + str(status.getBSCSRecording()) + u"TE録画中件数:" + str(status.getTERecording()) )
+    recdblist.printutf8(u"rec10処理開始"+ datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),verbose_level=800)
+    recdblist.printutf8(u"直近録画予約件数:" + str(inum) + u"BS/CS録画中件数:" + str(status.getBSCSRecording()) + u"TE録画中件数:" + str(status.getTERecording()) ,verbose_level=800)
     encodenum=0
     b25num=0
     dnow=datetime.datetime.now()
@@ -76,14 +76,14 @@ def task():
                 recnum = 0
                 if bctype.find('te') > -1:
                     recnum = status.getTERecording() + recdb.countRecNow_minutes_TE("10")
-                    recdblist.printutf8(u"放送種別:"+bctype + u"||該当チューナー実行中件数:" + str(status.getTERecording()) + u":直近予約件数:" + str(recdb.countRecNow_minutes_TE("10")))
+                    recdblist.printutf8(u"放送種別:"+bctype + u"||該当チューナー実行中件数:" + str(status.getTERecording()) + u":直近予約件数:" + str(recdb.countRecNow_minutes_TE("10")),verbose_level=800)
                     recnum = int(configreader.getenv("te_max")) -recnum
                 else:
                     recnum = status.getBSCSRecording() + recdb.countRecNow_minutes_BSCS("10")
-                    recdblist.printutf8(u"放送種別:"+bctype + u"||該当チューナー実行中件数:" + str(status.getBSCSRecording()) + u":直近予約件数:" + str(recdb.countRecNow_minutes_BSCS("10")))
+                    recdblist.printutf8(u"放送種別:"+bctype + u"||該当チューナー実行中件数:" + str(status.getBSCSRecording()) + u":直近予約件数:" + str(recdb.countRecNow_minutes_BSCS("10")),verbose_level=800)
                     recnum = int(configreader.getenv("bscs_max")) -recnum
                 if recnum >0 :
-                    recdblist.printutf8(str(update))
+                    recdblist.printutf8(str(update),verbose_level=750)
                     rec10d.rec10db.update_status_by_bctype_epg_ch(bctype, "0")
                     epgdb.updatebc(bctype)
                     update = chdb.update()
@@ -272,12 +272,12 @@ def search_keyword(key):
                             topt=status.getSettings_auto_opt()
                             recdb.recreserv(titlet,chtxtt, btimet, etimet,topt)
                     except Exception, inst:
-                        recdblist.Commonlogex("Error", "search_keyword_auto_jbk(timerec.py)", str(type(inst)),str(inst))
+                        recdblist.Commonlogex("Error", "search_keyword_auto_jbk(timerec.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
                 else:
                     try:
                         recdb.add_auto_keyword(chtxtt, titlet, btimet, etimet)
                     except Exception, inst:
-                        recdblist.Commonlogex("Error", "search_keyword(timerec.py)", str(type(inst)),str(inst))
+                        recdblist.Commonlogex("Error", "search_keyword(timerec.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
 def type_reserve(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -315,7 +315,7 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                     auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                     recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
                 except Exception, inst:
-                    recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst))
+                    recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
             else:
                 recdblist.printutf8(u"追いかけ機能エラー：番組データが見付かりません。")
         else:
@@ -343,15 +343,15 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                 auto_rec.add_key(chtxt, titlen,exp+" "+longexp)
                 auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                 #recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
-                recdblist.Commonlogex(u"通常", "Oikake (timerec.py)",u"追いかけ機能実行中",u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
+                recdblist.Commonlogex(u"通常", "Oikake (timerec.py)",u"追いかけ機能実行中",u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen,log_level=500)
             except Exception, inst:
-                recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst))
+                recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
     elif dt <= 20 * 60:
         try:
             recdb.del_reckey(typetxtnow, title, chtxt, btime)
             recdb.rec_reckey(typetxtfinal, title, chtxt, btime, etime, opt)
         except Exception, inst:
-            recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst))
+            recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
 def type_final(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -385,7 +385,7 @@ def type_final(typetxt,chtxt,title,bt,et,opt):
             newtime=bt
             newtitle=newtitle+u"_"+iff+newtime.strftime("%Y-%m-%dT%H-%M-%S")
         recdb.rec_reckey(typetxting, newtitle, chtxt, btime, etime, opt)
-        recdblist.Commonlogex(u"通常","timerec.py",u"録画開始 "+newtitle+" "+btime+" "+etime)
+        recdblist.Commonlogex(u"通常","timerec.py",u"録画開始 "+newtitle+" "+btime+" "+etime,"",log_level=500)
         tv2avi.timetv2b25(recpath + "/" + newtitle + ".avi", chtxt, btime, etime, opt)
         recdb.del_reckey(typetxting, newtitle, chtxt, btime)
         if not re.search("R", opt):
@@ -415,7 +415,7 @@ def type_keyword(typetxt,chtxt,title,bt,et,opt,deltatime):
     tnow = datetime.datetime.now()
     dtt = bt-tnow
     dt = dtt.days * 24 * 60 * 60 + dtt.seconds
-    print dt
+    recdblist.printutf8(str(dt), verbose_level=800)
     if dt < 90 * 60:
         recdata = epgdb.searchtime2(title, btime, deltatime, chtxt)
         if recdata[1] != "":
@@ -436,7 +436,7 @@ def type_keyword(typetxt,chtxt,title,bt,et,opt,deltatime):
             recdb.rec_reclog(titlet, chtxtt, btimet, etimet, opt, exp,longexp,category)
             auto_rec.add_key(chtxt, titlet,exp+" "+longexp)
             auto_rec.add_key("ALL", titlet,exp+" "+longexp)
-            recdblist.Commonlogex(u"通常","timerec.py",u"key "+title+u" : "+titlet+u" "+btimet+u" "+etimet,"")
+            recdblist.Commonlogex(u"通常","timerec.py",u"key "+title+u" : "+titlet+u" "+btimet+u" "+etimet,"",log_level=500)
             #except Exception, inst:
             #    recdblist.printutf8("Error happened in REC_KEYWORD DB")
             #    recdblist.printutf8(type(inst))
@@ -533,7 +533,7 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
                     errtxt1="move ts error.\n"
                     errtxt2=str(type(inst))+"\n"
                     errtxt2=errtxt2+str(inst)
-                    recdblist.Commonlogex("Error", "type_decode_que(timerec.py)", errtxt1,errtxt2)
+                    recdblist.Commonlogex("Error", "type_decode_que(timerec.py)", errtxt1,errtxt2+traceback.format_exc(),log_level=200)
                 recdb.rec_reckey(recdblist.REC_MOVE_END, title, chtxt, btime, etime, opt)
         else:
             recdb.del_reckey(typetxtnow, title, chtxt, btime)
@@ -654,7 +654,7 @@ def type_encode_que(typetxt,chtxt,title,bt,et,opt):
                     errtxt1="move mkv/mp4 error."
                     errtxt2=str(type(inst))+"\n"
                     errtxt2=errtxt2+str(inst)
-                    recdblist.Commonlogex("Error", "type_encode_que(timerec.py)", errtxt1,errtxt2)
+                    recdblist.Commonlogex("Error", "type_encode_que(timerec.py)", errtxt1,errtxt2+traceback.format_exc(),log_level=200)
                 recdb.rec_reckey(recdblist.REC_MOVE_END, title, chtxt, btime, etime, opt)
             recdb.rec_reckey(typetxtfin, title, chtxt, btime, etime, opt)
             sys.exit()
