@@ -12,6 +12,7 @@ import string
 import base64
 import time
 import subprocess
+import traceback
 
 import tv2avi
 import recdblist
@@ -46,6 +47,8 @@ def raw2mp4(pin,pout,opt):
         duration="-fps 29.970030 "##ffmpegが24fpsに対応していないための措置
     elif re.search("5",opt):
         duration="-fps 29.970030 "##ffmpegが24fpsに対応していないための措置
+    if re.search("I",opt):
+        duration="-fps 29.970030 "
     exe = configreader.getpath("mp4box")
     txt=""
     os.environ['LANG']="ja_JP.UTF-8"
@@ -133,15 +136,18 @@ def addAudio(pts,pmp4,opt):#オプションに応じた音声の追加を行う
             paac2=pts.replace(".ts","_2.mp3")
         e1a1=exe +u" -add \""+paac1+"\" \""+pmp4+"\""
         e1a2=exe +u" -add \""+paac2+"\" \""+pmp4+"\""
-        addmp4(paac1, pmp4, e1a1)
-        addmp4(paac2, pmp4, e1a2)
+        if os.path.exists(paac1):
+            addmp4(paac1, pmp4, e1a1)
+        if os.path.exists(paac2):
+            addmp4(paac2, pmp4, e1a2)
     else:
         tv2audio.ts2single_audio(pts)
         pinaac=pts.replace(".ts",".aac")
         if not os.path.exists(pinaac):
             pinaac=pinaac.replace(".aac",".mp3")
         e1a=exe +u" -add \""+pinaac+"\" \""+pmp4+"\""
-        addmp4(pinaac, pmp4, e1a)
+        if os.path.exists(pinaac):
+            addmp4(pinaac, pmp4, e1a)
 def execmp4box(pin,pout,cmd):
     title=os.path.splitext(os.path.split(pin)[1])[0]
     nt=base64.b16encode(title.encode('utf-8'))
@@ -162,6 +168,7 @@ def execmp4box(pin,pout,cmd):
         txt= "error occures in execmp4box\n"
         txt=txt+ str(type(inst))+"\n"
         txt=txt+str(inst)
+        recdblist.Commonlogex("Error", "excecmp4box(tv2mp4.py)", str(type(inst)), str(inst)+traceback.format_exc(),verbose_level=200,log_level=200)
     recdblist.addlog(pin, cmdn, u"MP4Boxログ-コマンド")
     recdblist.addlog(pin, txt, u"MP4Boxログ-詳細")
     time.sleep(5)
