@@ -5,6 +5,7 @@ import commands
 import os
 import os.path
 import time
+import traceback
 
 import configreader
 import status
@@ -29,7 +30,7 @@ def tv2ts(pout, ch, csch, time):
     try:
         tv2b25ts(pout + ".b25", ch, time)
     except Exception, inst:
-        recdblist.Commonlogex(u"Error",u"tv2ts(tv2ts.py)", str(type(inst)),str(inst))
+        recdblist.Commonlogex(u"Error",u"tv2ts(tv2ts.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
     if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
         status.changeBSCSRecording(-1)
     else:
