@@ -138,6 +138,16 @@ static STATION csSta[] = {
 };
 
 static int csStaCount = sizeof(csSta) / sizeof (STATION);
+
+static STATION huSta[] = {
+	{ "أ", "0013a.ontvjapan.com", 32744, 4, 1088},
+	{ "أ", "0013b.ontvjapan.com", 32744, 4, 1089},
+	{ "أ", "0013c.ontvjapan.com", 32744, 4, 1090},
+};
+
+static int huStaCount = sizeof(huSta) / sizeof (STATION);
+
+
 SVT_CONTROL	*svttop = NULL;
 #define		SECCOUNT	4
 char	title[1024];
@@ -350,6 +360,7 @@ int main(int argc, char *argv[])
 		fprintf(stdout, "ontvcode ͥ뼱̻ҡ****.ontvjapan.com ʤ\n");
 		fprintf(stdout, "/BS      BS⡼ɡĤTSBSɤΥǡɤ߹ߤޤ\n");
 		fprintf(stdout, "/CS      CS⡼ɡĤTSʣɤΥǡɤ߹ߤޤ\n");
+		fprintf(stdout, "/HU      إ⡼ɡĤTSɤΥǡɤ߹ߤޤ\n");
 		return 0;
 	}
 
@@ -361,6 +372,10 @@ int main(int argc, char *argv[])
 		pStas = csSta;
 		staCount = csStaCount;
 		act = 0 ;
+	}else if(strcmp(arg_onTV, "/HU") == 0){
+		pStas = huSta;
+		staCount = huStaCount;
+		act = 0 ;
 	}else{
 		act = 1 ;
 		svttop = calloc(1, sizeof(SVT_CONTROL));
